=================
Contributor Guide
=================

.. toctree::
    :hidden:

    github.rst
    setup.rst
    new_contrib.rst 
    documentation.rst

Espresso is a community project, and we welcome contributions! Ways you can get involved include:

- Report a bug or suggest a feature using the `Issue Tracker <newissue_>`_
- Join the conversation on `Slack`_
- Add a new test problem (or improve an existing one)
- Improve the documentation

This guide explains how to contribute to the Espresso code base. There is also a :doc:`../developer_guide/index` that explains some 'behind the scenes' aspects of our build system.



